%% INITIALISING

clear all; clc
path = ''; % Location of spike-times files
save_path = ''; % Save location for figures
CC_fold = ''; % Path of cross-correlation files produced by main_cc.m
T = 60; % Duration of each recording phase (min)
tbin = 30; % For analysing the parameters in smaller temporal episodes of length tbin (min)
warning('off','signal:findpeaks:largeMinPeakHeight'); % Disable matlab warnings when no dominant oscillation frequency is found
min_bursts = 20; % Minimal number of bursts to analyse burst-related parameters for a given MEA
keys = {['Treated' filesep 'Baseline'],['Treated' filesep 'LowConcentration'],['Treated' filesep 'HighConcentration'];...
    ['Control' filesep 'Baseline'],['Control' filesep 'LowConcentration'],['Control' filesep 'HighConcentration']}'; % Name of the different groups

blank_files = {['Treated' filesep 'Baseline' filesep '201508121023_I7490_div28_spikes.txt'],...
    ['Treated' filesep 'HighConcentration' filesep '201508121250_I7490_div28_spikes.txt'],...
    ['Treated' filesep 'LowConcentration' filesep '201508121134_I7490_div28_spikes.txt'],...
    ['Treated' filesep 'Baseline' filesep '201508121023_I7496_div28_spikes.txt'],...
    }; % Recordings needing blanking (i.e. ignoring its 'spikes') because of very high noise levels
blank_electrodes = {52,[52,54],52,20}; % Electrodes needing blanking (per file of blank_files respectively)


%% LOADING DATA

data = struct('type',{},'time',{},'nelec',{},'spikes',{},'bursts',{},'dur',{},'ibi',{},'mbr',{},'mfr',{}); % Initialising variable
for j = 1:numel(keys); data(j).type = keys{j}; end % The name of each condition
fprintf('--- LOADING RECORDINGS ---\nLoading & burst detection: ');
groups = dir(path); groups(1:2) = []; files = []; idx = ones(6,1); % Finding the group folders & Initialising variables
conditions = dir([path filesep groups(1).name]); conditions(1:2) = []; % Finding the different conditions per group
for group = 1:length(groups)
    for condition = 1:length(conditions)
        curr_path = [path filesep groups(group).name filesep conditions(condition).name]; % Current location
        f = dir(curr_path); f(1:2) = []; % All spike time files founds at current location
        files = [files strcat([curr_path filesep],{f.name})]; %#ok<AGROW> % Concatenating file names with current location
    end
end
for i = 1:length(files)
    spk = load(files{i}); % Loading spike times from each file
    tags = strsplit(files{i},filesep); ind = strcmp(tags,'Control') | strcmp(tags,'Treated'); % Identifying which condition the file belongs to
    j = strcmp(strcat(tags(ind),filesep,tags(find(ind)+1)),keys); j = j(:); % j is logical vector indicating which position in the 'data' structure this file belongs to
    % Blanking: Removing spikes from specific noisy electrodes
    blank_idx = cellfun(@strfind,repmat(files(i),1,length(blank_files)),blank_files,'uniformoutput',false); % Finding if the file matches one of the 'blacklised' files
    blank_idx = ~cellfun(@isempty,blank_idx); % Converting to logical vector
    if any(blank_idx) % When electrodes should be blanked for this file
        ind = false(size(spk,1),1); % Initialising logical vector
        for ii = 1:length(blank_electrodes{blank_idx}), ind = ind & spk(:,2) == blank_electrodes{blank_idx}(ii); end % For each electrode to be blanked, find the indices of the spikes belonging to these electrodes
        spk(ind,:) = []; % Removing selected spikes
        act_el_correction = length(blank_electrodes{blank_idx}); % When electrodes are removed because of noise, the total possible number of active electrode (59) should be decreased as well by this factor
    else act_el_correction = 0; % In case no electrodes are blanked, total possible number of electrodes remains the same, so factor should be 0
    end
    % Active electrodes (Only consider electrodes active if they fire at more than 0.02 Hz)
    Nactive_electrodes = sum(histc(spk(:,2),1:60)/(T*60) > 0.02); % Counting active electrodes by binning all spikes per electrode, testing whether they had sufficinelty high average firing rate, then summing the resulting logical vector
    % Burst detection
    bursts = burst_detection(spk,T*60*1e3,Nactive_electrodes-act_el_correction); % Detecting burst events from the spike trains
    % Storing info in data structure
    data(j).nelec(idx(j)) = Nactive_electrodes/(59-act_el_correction); % Normalising number of active electrodes
    data(j).time = T*60; % Lenght of recording (min)
    n_bins = ceil(data(j).time/(tbin*60)); % Number of episodes each recording will be split and analysed seperatly in
    for t = 1:n_bins
        spike_idx = (spk(:,1) > (t-1)*tbin*60*1e3) & (spk(:,1) <= t*tbin*60*1e3); % Index of spikes belonging to current episode
        burst_idx = (bursts.tpeaks > (t-1)*tbin*60*1e3) & (bursts.tpeaks <= t*tbin*60*1e3); % Index of bursts belonging to current episode
        ibi_idx = burst_idx; tmp = find(burst_idx); if any(ibi_idx); ibi_idx(tmp(end)) = []; end % Index of interburst intervals
        data(j).spikes{idx(j),t} = spk(spike_idx,:); % Saving spike times to data structure
        data(j).mfr(idx(j),t) = sum(spike_idx)/(tbin*60)/Nactive_electrodes; % Saving mean firing rate per electrode to data structure
        data(j).bursts{idx(j),t} = bursts.tpeaks(burst_idx); % Saving bursts to data structure
        if cellfun(@length,data(j).bursts(idx(j),1:t)) > min_bursts % If there are enough bursts
            data(j).mbr(idx(j),t) = sum(burst_idx)/(tbin*60); % Saving mean burst rate to data structure
            data(j).dur{idx(j),t} = bursts.DUR(burst_idx); % Saving burst durations to data structure
            data(j).ibi{idx(j),t} = bursts.IBI(ibi_idx)/1e3; % Saving interburst intervals to data structure
        else
            data(j).mbr(idx(j),t) = NaN; % If not enough bursts
            data(j).dur{idx(j),t} = []; % If not enough bursts
            data(j).ibi{idx(j),t} = []; % If not enough bursts
        end
    end
    idx(j) = idx(j) + 1; % Increasing the counter for the current condition
end
fprintf('\n')


%% BURST ALIGNMENT & ANALYSIS

disp('--- BURST ALIGNMENT & ANALYSIS ---'); recalc_count = 0;
for i = 1:numel(keys) % Looping over conditions
    fprintf('Condition %s: ',keys{i})
    for j = 1:size(data(i).spikes,1) % Looping over samples per condition
        for t = 1:n_bins % Looping over number of episodes
            redo = 'y'; % Initialising variable
            while strcmpi(redo,'y') % In case burst alignment was unsuccessful
                if length(data(i).bursts{j,t}) < min_bursts % If not enough bursts: save to data structure & continue with next loop iteration
                    data(i).psd{j,t} = NaN; data(i).peak_freq(j,t) = NaN; data(i).peak_power(j,t) = NaN; data(i).slope(j,t) = NaN; ...
                        data(i).fittedregion{j,t} = NaN; data(i).fitR(j) = NaN; data(i).F{j,t} = NaN; continue
                end
                answ = 0; % Initialising variable
                % Burst alignment for maximal correlation
                while answ == 0 % Until correlation of aligned bursts is sufficiently high
                    [new_burst_profile,time_profile,psd,freq,delays,R] = burst_alignment(data(i).bursts{j,t},data(i).spikes{j,t},1,0);
                    if mean(R) < 0.3; recalc_count = recalc_count + 1; else answ = 1; end % Initial check on performance of correlation: should be at least 0.3
                end
                data(i).burst_profile{j,t} = mean(new_burst_profile); % Mean burst profile: Averaging over all aligned bursts
                data(i).psd{j,t} = mean(psd); % Averaging over all power spectra of each burst
                % Power spectrum
                threshold = 3*median(data(i).psd{j,t}(15:end)); % Calculating threshold for dominant frequencies (ignoring lowest frequencies)
                crossing = find(abs(diff(data(i).psd{j,t} > threshold))); % Finding where power spectrum crosses threshold
                tmp = diff(crossing); if ~isempty(tmp) && tmp(1) == 1; flag = 1; else flag = 0; end % When PSD drops below threshold for only 1 value at the start
                if rem(length(crossing),2); crossing(1) = []; else crossing(1:2) = []; end % Deleting threshold crossings related to initial (low-freq) peak in PSD
                if ~isempty(crossing) && flag; crossing(1:2) = []; end % Ignoring false initial crossings
                if ~isempty(crossing)
                    idx_correction = repmat([1 0],1,length(crossing)/2); idx = crossing + idx_correction; % Adjusting index values
                    power = zeros(length(idx)/2,1); peak_freq = zeros(length(idx)/2,1); % Initialising variables
                    for ii = 1:length(idx)/2
                        [power(ii),peak_freq(ii)] = max(data(i).psd{j,t}(idx(ii*2-1):idx(ii*2))); % Extracting the maximum value per pair of threshold crossings
                        peak_freq(ii) = peak_freq(ii) + idx(ii*2-1) - 1; % Frequency belonging to maximum
                    end
                    [~,idx] = max(power); % Largest peak from the local maxima
                    data(i).peak_freq(j,t) = freq(peak_freq(idx)+1); % Saving dominant frequency to data structure
                    data(i).peak_power(j,t) = power(idx); % Saving dominant frequency's power to data structure
                else
                    data(i).peak_freq(j,t) = NaN; % If no dominant frequency is found
                    data(i).peak_power(j,t) = NaN; % If no dominant frequency is found
                end
                % Fitting burst rise phase
                sr = 1/(time_profile(2)-time_profile(1)); % Sampling rate of average aligned burst profile (1/dt)
                threshold = (max(data(i).burst_profile{j,t})-min(data(i).burst_profile{j,t}))*0.85; % Setting threshold at 85% of max burst profile amplitude
                [peak,loc] = findpeaks(data(i).burst_profile{j,t},'minpeakdistance',5,'minpeakheight',threshold); % Finding the peak of the mean burst profile
                peak = peak(1); loc = loc(1); % First peak is largest
                to_fit1a = 75; % Time in ms of baseline to include for fitting
                to_fit1b = 5; % Minimum amplitude required to be included for fitting (percentage of peak amplitude)
                to_fit2 = 60; % (percentage of peak amplitude)
                % threshold = 25*median(data(i).burst_profile{j,t}(1:100));
                to_fit1b = find(data(i).burst_profile{j,t}-data(i).burst_profile{j,t}(1) > (peak-data(i).burst_profile{j,t}(1))*to_fit1b/1e2); % Finding part of burst profile above 5% of peak amplitude
                to_fit1a = to_fit1b(1)-to_fit1a/sr*1e3; if to_fit1a < 1; to_fit1a = 1; end % Taking 75 ms before first point reaching 5% of peak amplitude
                to_fit2 = find(data(i).burst_profile{j,t} > peak*to_fit2/1e2); % Finding part of burst profile above 60% of peak amplitude
                trace = data(i).burst_profile{j,t}(to_fit1a:to_fit2(1)-1); % Taking part of burst profile to fit
                func = fittype('a0 * (exp( (b0-1) * x)) + a1 * (exp( (b1-1) * x)) + d'); % Function to fit
                opt = fitoptions('Method','NonlinearLeastSquares','Startpoint',[0.2 0.2 1.090 1.05 2],'Lower',[1e-12 0.001 1.0001 1.0001 -10],'Upper',[10 10 2 2 50]); % Fit options
                T = (0:sr/1e3:length(trace)-1); % Time belonging to burst profile part
                [F,G] = fit(T',trace',func,opt); % Fitting
                data(i).slope(j,t) = F.b0; % Extracting the slope parameter
                data(i).fitR(j,t) = G.adjrsquare; % Fit goodness
                data(i).fittedregion{j,t} = [to_fit1a to_fit2(1)]; % Indexes of burst profile used for fitting
                data(i).F{j,t} = F; % Fitted function
                % figure('color','w','position',[1 31 1920 973]); hold on;
                % time = 0:length(data(i).burst_profile{j,t})-1; plot(time,data(i).burst_profile{j,t},'k');
                % plot(time(data(i).fittedregion{j,t}(1):data(i).fittedregion{j,t}(2)),data(i).burst_profile{j,t}(data(i).fittedregion{j,t}(1):...
                %     data(i).fittedregion{j,t}(2))); plot(time(data(i).fittedregion{j,t}(1):data(i).fittedregion{j,t}(2)),...
                %     data(i).F{j,t}(1:diff(data(i).fittedregion{j,t})+1),'r'); title(sprintf('%d, %d, %d',i,j,t))
                redo = input('Redo burst alignment & fitting? [y/N] ','s'); % Decision to redo or keep burst alignment after manual inspection
            end
        end
    end
end
fprintf('Bad alignment detected & resolved in %d cases\n\n',recalc_count);


%% CROSS CORRELATION

% main_cc(path,CC_fold); % Run once to generate the CC files required below

fprintf('--- CROSS CORRELATION ---\nProgress: ');
CC_files = dir(CC_fold); CC_files(1:2) = []; % Finding CC files
data(1).peak_matrix = []; data(1).lag_matrix = []; % Initialising variables
for i = 1:length(CC_files)
    load(strcat(CC_fold,filesep,CC_files(i).name)) % Loading CC variables
    tmp = strsplit(CC_files(i).name,'.');
    group = str2double(tmp{1}(end)); % Finding matching condition index
    sub = str2double(tmp{2}); % Finding matching condition index
    data(group).peak_matrix{sub} = peak_matrix; % Saving cross-correlogram peak values to data structure
    data(group).lag_matrix{sub} = lag_matrix; % Saving the cross-correlogram peak's time lag values to data structure
end

cc_delta = cell(1,2); all_cc_delta = cell(1,2); % Initialising variables
for i = [1:2 4:5]
    for j = 1:length(data(i).peak_matrix)
        if length(data(i).peak_matrix) == 10; ii=0; elseif length(data(i).peak_matrix) == 7; ii=3; end % Differentiating between treated & control
        % Latency check (Cpeaks with opposite time-delay signs (of at least a delay difference of 2*bin size) should not be compared)
        tmp = find((sign(data(1+i).lag_matrix{j}./data(1+ii).lag_matrix{j}) == -1) & ...
            (abs(data(1+i).lag_matrix{j}-data(1+ii).lag_matrix{j}) > 2*3)); % Finding values that don't pass the latency check
        del_idx = [rem(tmp,60) ceil(tmp/60)]; % Index of values that don't pass the latency check
        for jj = 1:size(del_idx,1); data(1+i).peak_matrix{j}(del_idx(jj,1),del_idx(jj,2)) = NaN; end % Deleting values that don't pass the latency check
        % Calculating change in Cpeak
        delta = data(1+i).peak_matrix{j}./data(1+ii).peak_matrix{j}; % Dividing values after by values before
        cc_delta{ii/3+1}(j,i-ii) = nanmean(delta(:)); % Mean change per MEA in CC peak values
        all_cc_delta{i-ii/3}{j} = delta; % Individual changes (per electrode pair) in CC peak values
    end
end
fprintf('\n')


%% PLOTTING

disp('--- PLOTTING ---');
% ------------- % Plot 1 % ------------- %
[fig1,ax] = populated_fig([25 45],[0.10 0.10],[0.10 0.10],[2 3],1);
plot_color = {[0 150 255]/255,[.55 .55 .55]}; % Plot color
plot_color_shaded = {[125 225 255]/255,[.55 .55 .55]+.30}; % White-shifted plot color
fnt_size = [16 12]; typeface = 'Helvetica'; dot_size = 25; % Axis properties
sig_levels = [0.05 0.01 0.001]; % Statistic test significance levels
xlab = cell(1,n_bins); for i = 1:n_bins; xlab{i} = sprintf('%d',i*tbin); end % Labels for time periods
conc_lab = {'100 nM',sprintf('10 \\muM')}; % Concentration labels
horz_bar_length = 0.12; horz_bar_width = 3; % Bar settings
bar_width = 0.7; spacing = 0.3; % Bar plot layout
d_intra_conc = 0.15; d_inter_conc = 0.25; % Spacing within and between groups
x_positions = repmat([-d_inter_conc/2-d_intra_conc -d_inter_conc/2 d_inter_conc/2 d_inter_conc/2+d_intra_conc],2,1); % X-axis location
x_positions = x_positions + repmat([1; 2],1,4); % X-axis location
textbox_length = .15; textbox_height = .05; % Textbox dimensions

% ACTIVE ELECTRODES
pos = 1; axes(ax(pos)); hold(ax(pos),'on')
for conc = 1:2 % For each concentration
    % uPA treated
    par1 = data(conc+1).nelec./data(1).nelec; % Normalisation of treated parameter
    loc1 = (bar_width+spacing)*2*conc-1+bar_width/2; % Location of treated parameter
    bar(loc1,mean(par1),'FaceColor',plot_color{1},'BarWidth',bar_width,'Linewidth',1,'LineWidth',1);
    errorbar(loc1,mean(par1),std(par1)/sqrt(length(par1)),'LineStyle','none','Color',[0 0 0],'LineWidth',1);
    bar(loc1,mean(par1),'FaceColor',plot_color{1},'BarWidth',bar_width,'Linewidth',1,'LineWidth',1);
    % DMSO treated
    par2 = data(conc+4).nelec./data(4).nelec; % Normalisation of control parameter
    loc2 = (bar_width+spacing)*2*conc-1-bar_width/2; % Location of control parameter
    bar(loc2,mean(par2),'FaceColor',plot_color{2}+0.15,'BarWidth',bar_width,'Linewidth',1,'LineWidth',1);
    errorbar(loc2,mean(par2),std(par2)/sqrt(length(par2)),'LineStyle','none','Color',[0 0 0],'LineWidth',1);
    bar(loc2,mean(par2),'FaceColor',plot_color{2}+0.15,'BarWidth',bar_width,'Linewidth',1,'LineWidth',1);
    % Statistics
    stat = MWUtest(par1,par2,0); % Mann-Whitney U test
    sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
    if any(sig); sigstar({[loc2,loc1]},sign_levels(sig(end))); end % Plotting in case of significance
end
% Formating
set(gca,'xlim',[0 (bar_width+spacing)*4],'xticklabel',{'100 nM','10 M'},'xtick',[1 3],'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Normalised active electrodes','fontsize',fnt_size(1),'fontname',typeface); ylim([0 1.1]);

% FIRING RATE
pos = 2; axes(ax(pos)); hold(ax(pos),'on');
for conc = 1:2 % For each concentration
    % uPA treated
    par1 = data(conc+1).mfr./repmat(mean(data(1).mfr,2),1,2); % Normalisation of treated parameter
    loc1 = x_positions(2,conc*2-1:conc*2); % Location of treated parameter
    plot(loc1,par1,'-','color',plot_color{1}) % Connecting lines
    plot(loc1,par1,'.','markersize',dot_size,'color',plot_color{1}) % Data points
    plot([loc1(1)-horz_bar_length/2 loc1(1)+horz_bar_length/2],[nanmean(par1(:,1)) nanmean(par1(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc1(2)-horz_bar_length/2 loc1(2)+horz_bar_length/2],[nanmean(par1(:,2)) nanmean(par1(:,2))],'k','linewidth',horz_bar_width) % Average
    % DMSO treated
    par2 = data(conc+4).mfr./repmat(mean(data(4).mfr,2),1,2); % Normalisation of control parameter
    loc2 = x_positions(1,conc*2-1:conc*2); % Location of control parameter
    plot(loc2,par2','-','color',plot_color{2}) % Connecting lines
    plot(loc2,par2','.','markersize',dot_size,'color',plot_color{2}+0.1) % Data points
    plot([loc2(1)-horz_bar_length/2 loc2(1)+horz_bar_length/2],[nanmean(par2(:,1)) nanmean(par2(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc2(2)-horz_bar_length/2 loc2(2)+horz_bar_length/2],[nanmean(par2(:,2)) nanmean(par2(:,2))],'k','linewidth',horz_bar_width) % Average
    % Statistics
    for i = 1:n_bins % For each period
        stat = MWUtest(par1(:,i),par2(:,i),0); % Mann-Whitney U test
        sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
        if any(sig); sigstar({[loc2(i),loc1(i)]},sig_levels(sig(end))); end % Plotting in case of significance
    end
end
plot(x_positions(2,2:3),[data(2).mfr(:,2) data(3).mfr(:,1)]./repmat(mean(data(1).mfr,2),1,2),'-.','color',plot_color_shaded{1}) % Connecting lines
plot(x_positions(1,2:3),[data(5).mfr(:,2) data(6).mfr(:,1)]./repmat(mean(data(4).mfr,2),1,2),'-.','color',plot_color_shaded{2}) % Connecting lines
% Formating
set(gca,'xlim',[.5 2.5],'xticklabel',xlab,'xtick',sort(x_positions(:)),'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Normalised firing rate','fontsize',fnt_size(1),'fontname',typeface)
ax_lab_pos = mean(reshape(x_positions',2,4)); x_lim = get(gca,'xlim'); % Calculating position of concentration labels
rel_lab_pos = (ax_lab_pos-x_lim(1))/diff(x_lim); axis_pos = get(gca,'position'); % Calculating position of concentration labels
lab_pos = rel_lab_pos*axis_pos(3) + axis_pos(1); % Calculating position of concentration labels
for i = 1:length(lab_pos) % Adding concentration labels
    annotation('textbox','position',[lab_pos(i)-textbox_length/2 axis_pos(2)-textbox_height textbox_length textbox_height],'string',conc_lab{~rem(i,2)+1},...
        'edgecolor','none','horizontalalignment','center','verticalalignment','middle','fontsize',fnt_size(2),'fontname',typeface)
end
    
% BURST RATE
pos = 3; axes(ax(pos)); hold(ax(pos),'on');
for conc = 1:2 % For each concentration
    % uPA treated
    par1 = data(conc+1).mbr./repmat(mean(data(1).mbr,2),1,2); % Normalisation of treated parameter
    loc1 = x_positions(2,conc*2-1:conc*2); % Location of treated parameter
    plot(loc1,par1,'-','color',plot_color{1}) % Connecting lines
    plot(loc1,par1,'.','markersize',dot_size,'color',plot_color{1}) % Data points
    plot([loc1(1)-horz_bar_length/2 loc1(1)+horz_bar_length/2],[nanmean(par1(:,1)) nanmean(par1(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc1(2)-horz_bar_length/2 loc1(2)+horz_bar_length/2],[nanmean(par1(:,2)) nanmean(par1(:,2))],'k','linewidth',horz_bar_width) % Average
    % DMSO treated
    par2 = data(conc+4).mbr./repmat(mean(data(4).mbr,2),1,2); % Normalisation of control parameter
    loc2 = x_positions(1,conc*2-1:conc*2); % Location of control parameter
    plot(loc2,par2','-','color',plot_color{2}) % Connecting lines
    plot(loc2,par2','.','markersize',dot_size,'color',plot_color{2}+0.1) % Data points
    plot([loc2(1)-horz_bar_length/2 loc2(1)+horz_bar_length/2],[nanmean(par2(:,1)) nanmean(par2(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc2(2)-horz_bar_length/2 loc2(2)+horz_bar_length/2],[nanmean(par2(:,2)) nanmean(par2(:,2))],'k','linewidth',horz_bar_width) % Average
    % Statistics
    for i = 1:n_bins % For each period
        x1 = par1(:,i); x1(~isfinite(x1)) = [];
        x2 = par2(:,i); x2(~isfinite(x2)) = [];
        stat = MWUtest(x1,x2,0); % Mann-Whitney U test
        sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
        if any(sig); sigstar({[loc2(:,i),loc1(:,i)]},sig_levels(sig(end))); end % Plotting in case of significance
    end
end
plot(x_positions(2,2:3),[data(2).mbr(:,2) data(3).mbr(:,1)]./repmat(mean(data(1).mbr,2),1,2),'-.','color',plot_color_shaded{1}) % Connecting lines
plot(x_positions(1,2:3),[data(5).mbr(:,2) data(6).mbr(:,1)]./repmat(mean(data(4).mbr,2),1,2),'-.','color',plot_color_shaded{2}) % Connecting lines
% Formating
set(gca,'xlim',[.5 2.5],'xticklabel',xlab,'xtick',sort(x_positions(:)),'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Normalised burst rate','fontsize',fnt_size(1),'fontname',typeface)
ax_lab_pos = mean(reshape(x_positions',2,4)); x_lim = get(gca,'xlim'); % Calculating position of concentration labels
rel_lab_pos = (ax_lab_pos-x_lim(1))/diff(x_lim); axis_pos = get(gca,'position'); % Calculating position of concentration labels
lab_pos = rel_lab_pos*axis_pos(3) + axis_pos(1); % Calculating position of concentration labels
for i = 1:length(lab_pos) % Adding concentration labels
    annotation('textbox','position',[lab_pos(i)-textbox_length/2 axis_pos(2)-textbox_height textbox_length textbox_height],'string',conc_lab{~rem(i,2)+1},...
        'edgecolor','none','horizontalalignment','center','verticalalignment','middle','fontsize',fnt_size(2),'fontname',typeface)
end

% BURST DURATION
pos = 4; axes(ax(pos)); hold(ax(pos),'on');
for conc = 1:2 % For each concentration
    % uPA treated
    par1 = cellfun(@mean,data(conc+1).dur)./repmat(mean(cellfun(@mean,data(1).dur),2),1,2); % Normalisation of treated parameter
    loc1 = x_positions(2,conc*2-1:conc*2); % Location of treated parameter
    plot(loc1,par1,'-','color',plot_color{1}) % Connecting lines
    plot(loc1,par1,'.','markersize',dot_size,'color',plot_color{1}) % Data points
    plot([loc1(1)-horz_bar_length/2 loc1(1)+horz_bar_length/2],[nanmean(par1(:,1)) nanmean(par1(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc1(2)-horz_bar_length/2 loc1(2)+horz_bar_length/2],[nanmean(par1(:,2)) nanmean(par1(:,2))],'k','linewidth',horz_bar_width) % Average
    % DMSO treated
    par2 = cellfun(@mean,data(conc+4).dur)./repmat(mean(cellfun(@mean,data(4).dur),2),1,2); % Normalisation of control parameter
    loc2 = x_positions(1,conc*2-1:conc*2); % Location of control parameter
    plot(loc2,par2','-','color',plot_color{2}) % Connecting lines
    plot(loc2,par2','.','markersize',dot_size,'color',plot_color{2}+0.1) % Data points
    plot([loc2(1)-horz_bar_length/2 loc2(1)+horz_bar_length/2],[nanmean(par2(:,1)) nanmean(par2(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc2(2)-horz_bar_length/2 loc2(2)+horz_bar_length/2],[nanmean(par2(:,2)) nanmean(par2(:,2))],'k','linewidth',horz_bar_width) % Average
    % Statistics
    for i = 1:n_bins % For each period
        x1 = par1(:,i); x1(~isfinite(x1)) = [];
        x2 = par2(:,i); x2(~isfinite(x2)) = [];
        stat = MWUtest(x1,x2,0); % Mann-Whitney U test
        sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
        if any(sig); sigstar({[loc2(:,i),loc1(:,i)]},sig_levels(sig(end))); end % Plotting in case of significance
    end
end
plot(x_positions(2,2:3),[cellfun(@mean,data(2).dur(:,2)) cellfun(@mean,data(3).dur(:,1))]./repmat(mean(cellfun(@mean,data(1).dur),2),1,2),'-.','color',plot_color_shaded{1}) % Connecting lines
plot(x_positions(1,2:3),[cellfun(@mean,data(5).dur(:,2)) cellfun(@mean,data(6).dur(:,1))]./repmat(mean(cellfun(@mean,data(4).dur),2),1,2),'-.','color',plot_color_shaded{2}) % Connecting lines
% Formating
set(gca,'xlim',[.5 2.5],'xticklabel',xlab,'xtick',sort(x_positions(:)),'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Normalised burst duration','fontsize',fnt_size(1),'fontname',typeface)
ax_lab_pos = mean(reshape(x_positions',2,4)); x_lim = get(gca,'xlim'); % Calculating position of concentration labels
rel_lab_pos = (ax_lab_pos-x_lim(1))/diff(x_lim); axis_pos = get(gca,'position'); % Calculating position of concentration labels
lab_pos = rel_lab_pos*axis_pos(3) + axis_pos(1); % Calculating position of concentration labels
for i = 1:length(lab_pos) % Adding concentration labels
    annotation('textbox','position',[lab_pos(i)-textbox_length/2 axis_pos(2)-textbox_height textbox_length textbox_height],'string',conc_lab{~rem(i,2)+1},...
        'edgecolor','none','horizontalalignment','center','verticalalignment','middle','fontsize',fnt_size(2),'fontname',typeface)
end

% CV OF IBI
pos = 5; axes(ax(pos)); hold(ax(pos),'on'); var1 = nan(size(data(1).ibi,1),2); var2 = nan(size(data(4).ibi,1),2);
for conc = 1:2 % For each concentration
    % uPA treated
    cv2 = cellfun(@std,data(conc+1).ibi)./cellfun(@mean,data(conc+1).ibi); % Coefficient of variation of treated group
    cv1 = nan(size(data(1).ibi,1),1); % Coefficient of variation of baseline group
    for mea = 1:size(data(1).ibi,1); cv1(mea) = std(cat(1,data(1).ibi{mea,:}))/mean(cat(1,data(1).ibi{mea,:})); end
    par1 = cv2./repmat(cv1,1,2); % Normalisation of treated parameter
    loc1 = x_positions(2,conc*2-1:conc*2); % Location of treated parameter
    plot(loc1,par1,'-','color',plot_color{1}) % Connecting lines
    plot(loc1,par1,'.','markersize',dot_size,'color',plot_color{1}) % Data points
    plot([loc1(1)-horz_bar_length/2 loc1(1)+horz_bar_length/2],[nanmean(par1(:,1)) nanmean(par1(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc1(2)-horz_bar_length/2 loc1(2)+horz_bar_length/2],[nanmean(par1(:,2)) nanmean(par1(:,2))],'k','linewidth',horz_bar_width) % Average
    % DMSO treated
    cv2 = cellfun(@std,data(conc+4).ibi)./cellfun(@mean,data(conc+4).ibi); % Coefficient of variation of treated group
    cv1 = nan(size(data(4).ibi,1),1); % Coefficient of variation of baseline group
    for mea = 1:size(data(4).ibi,1); cv1(mea) = std(cat(1,data(4).ibi{mea,:}))/mean(cat(1,data(4).ibi{mea,:})); end
    par2 = cv2./repmat(cv1,1,2); % Normalisation of control parameter
    loc2 = x_positions(1,conc*2-1:conc*2); % Location of control parameter
    plot(loc2,par2','-','color',plot_color{2}) % Connecting lines
    plot(loc2,par2','.','markersize',dot_size,'color',plot_color{2}+0.1) % Data points
    plot([loc2(1)-horz_bar_length/2 loc2(1)+horz_bar_length/2],[nanmean(par2(:,1)) nanmean(par2(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc2(2)-horz_bar_length/2 loc2(2)+horz_bar_length/2],[nanmean(par2(:,2)) nanmean(par2(:,2))],'k','linewidth',horz_bar_width) % Average
    % Statistics
    for i = 1:n_bins % For each period
        x1 = par1(:,i); x1(~isfinite(x1)) = []; % Removing infinite values
        x2 = par2(:,i); x2(~isfinite(x2)) = []; % Removing infinite values
        stat = MWUtest(x1,x2,0); % Mann-Whitney U test
        sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
        if any(sig); sigstar({[loc2(:,i),loc1(:,i)]},sig_levels(sig(end))); end % Plotting in case of significance
    end
    var1(:,conc) = par1(:,~(conc-1)+1); % Selecting data for connecting lines
    var2(:,conc) = par2(:,~(conc-1)+1); % Selecting data for connecting lines
end
plot(x_positions(2,2:3),var1,'-.','color',plot_color_shaded{1}) % Connecting lines
plot(x_positions(1,2:3),var2,'-.','color',plot_color_shaded{2}) % Connecting lines
% Formating
set(gca,'xlim',[.5 2.5],'xticklabel',xlab,'xtick',sort(x_positions(:)),'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Normalised CV of interburst intervals','fontsize',fnt_size(1),'fontname',typeface)
ax_lab_pos = mean(reshape(x_positions',2,4)); x_lim = get(gca,'xlim'); % Calculating position of concentration labels
rel_lab_pos = (ax_lab_pos-x_lim(1))/diff(x_lim); axis_pos = get(gca,'position'); % Calculating position of concentration labels
lab_pos = rel_lab_pos*axis_pos(3) + axis_pos(1); % Calculating position of concentration labels
for i = 1:length(lab_pos) % Adding concentration labels
    annotation('textbox','position',[lab_pos(i)-textbox_length/2 axis_pos(2)-textbox_height textbox_length textbox_height],'string',conc_lab{~rem(i,2)+1},...
        'edgecolor','none','horizontalalignment','center','verticalalignment','middle','fontsize',fnt_size(2),'fontname',typeface)
end

print(fig1,'-dpdf','-loose',strcat(save_path,filesep,'Firing & bursting')); % Saving figure as pdf
print(fig1,'-djpeg','-loose',strcat(save_path,filesep,'Firing & bursting')); % Saving figure as jpeg
close(fig1)


%%
% ------------- % Plot 2 % ------------- %
[fig2,ax] = populated_fig([35 25],[0.08 0.10], [0.10 0.10], [2 2], 0);

% ALIGNED BURST PROFILE: REPRESENTATIVE EXAMPLE
example = [1 5 2]; % Indices of selected representative example
pos = 1; axes(ax(pos)); hold(ax(pos),'on');
burst_profile = data(example(1)).burst_profile{example(2),example(3)}; % Selected burst profile
var1 = data(example(1)).fittedregion{example(2),example(3)}; start = var1(1); stop = var1(2); % Selected fitted region
plot(time_profile*1e3,burst_profile,'k','linewidth',1) % Burst profile
plot(time_profile(1)*1e3+(start:stop-1)-1,data(example(1)).F{example(2),example(3)}(0:stop-start-1),'color',[200 50 50]/255,'linewidth',2) % Fit
% Formating
xlabel('Time (ms)','fontsize',fnt_size(1),'fontname',typeface)
ylabel('Firing rate (Hz)','fontsize',fnt_size(1),'fontname',typeface)
ymax = get(gca,'ylim'); ymax = ymax(2);
set(gca,'fontsize',fnt_size(2),'ylim',[0 ymax*.9],'xlim',[-125 300],'fontname',typeface)

% PSD: REPRESENTATIVE EXAMPLE
example = [1 1 2]; % Indices of selected representative example
pos = 2; axes(ax(pos)); hold(ax(pos),'on');
cond_color = {[200 225 200]/255,[125 175 255]/255,[200 125 75]/255}; % Gray/Blue/Orange as Baseline/Low/High concentration
for i = 1:3; plot(freq,data(i).psd{example(2),example(3)},'linewidth',2,'color',cond_color{i}); end % Plotting frequency spetrum
xlabel('Frequency (Hz)','fontsize',fnt_size(1),'fontname',typeface); ylabel('Power (a.u.)','fontsize',fnt_size(1),'fontname',typeface); %title('Example of PSD','fontsize',20)
ylim([0 data(example(1)).peak_power(example(2),example(3))*1.5]); xlim([0 data(example(1)).peak_freq(example(2),example(3))*2.5]); %legend({'Baseline','100 nM','10 M'})
set(gca,'fontsize',fnt_size(2),'fontname',typeface,'clipping','off')

% SLOPE OF INITIAL RISING PHASE
pos = 3; axes(ax(pos)); hold(ax(pos),'on');
for conc = 1:2 % For each concentration
    % uPA treated
    par1 = data(conc+1).slope./repmat(mean(data(1).slope,2),1,2); % Normalisation of treated parameter
    loc1 = x_positions(2,conc*2-1:conc*2); % Location of treated parameter
    plot(loc1,par1,'-','color',plot_color{1}) % Connecting lines
    plot(loc1,par1,'.','markersize',dot_size,'color',plot_color{1}) % Data points
    plot([loc1(1)-horz_bar_length/2 loc1(1)+horz_bar_length/2],[nanmean(par1(:,1)) nanmean(par1(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc1(2)-horz_bar_length/2 loc1(2)+horz_bar_length/2],[nanmean(par1(:,2)) nanmean(par1(:,2))],'k','linewidth',horz_bar_width) % Average
    % DMSO treated
    par2 = data(conc+4).slope./repmat(mean(data(4).slope,2),1,2); % Normalisation of control parameter
    loc2 = x_positions(1,conc*2-1:conc*2); % Location of control parameter
    plot(loc2,par2','-','color',plot_color{2}) % Connecting lines
    plot(loc2,par2','.','markersize',dot_size,'color',plot_color{2}+0.1) % Data points
    plot([loc2(1)-horz_bar_length/2 loc2(1)+horz_bar_length/2],[nanmean(par2(:,1)) nanmean(par2(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc2(2)-horz_bar_length/2 loc2(2)+horz_bar_length/2],[nanmean(par2(:,2)) nanmean(par2(:,2))],'k','linewidth',horz_bar_width) % Average
    % Statistics
    for i = 1:n_bins % For each period
        x1 = par1(:,i); x1(~isfinite(x1)) = []; % Removing infinite values
        x2 = par2(:,i); x2(~isfinite(x2)) = []; % Removing infinite values
        stat = MWUtest(x1,x2,0); % Mann-Whitney U test
        sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
        if any(sig); sigstar({[loc2(:,i),loc1(:,i)]},sig_levels(sig(end))); end % Plotting in case of significance
    end
end
plot(x_positions(2,2:3),[data(2).slope(:,2) data(3).slope(:,1)]./repmat(mean(data(1).slope,2),1,2),'-.','color',plot_color_shaded{1}) % Connecting lines
plot(x_positions(1,2:3),[data(5).slope(:,2) data(6).slope(:,1)]./repmat(mean(data(4).slope,2),1,2),'-.','color',plot_color_shaded{2}) % Connecting lines
% Formating
set(gca,'xlim',[0.5 2.5*inter_sp],'ylim',[0.75 1.25],'xticklabel',xlab,'xtick',sort(x_positions(:)),'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Normalised rising phase exponent','fontsize',fnt_size(1),'fontname',typeface)
ax_lab_pos = mean(reshape(x_positions',2,4)); x_lim = get(gca,'xlim'); % Calculating position of concentration labels
rel_lab_pos = (ax_lab_pos-x_lim(1))/diff(x_lim); axis_pos = get(gca,'position'); % Calculating position of concentration labels
lab_pos = rel_lab_pos*axis_pos(3) + axis_pos(1); % Calculating position of concentration labels
for i = 1:length(lab_pos) % Adding concentration labels
    annotation('textbox','position',[lab_pos(i)-textbox_length/2 axis_pos(2)-.07 textbox_length textbox_height],'string',conc_lab{~rem(i,2)+1},...
        'edgecolor','none','horizontalalignment','center','verticalalignment','middle','fontsize',fnt_size(2),'fontname',typeface)
end

% DOMINANT PSD FREQUENCY
pos = 4; axes(ax(pos)); hold(ax(pos),'on');
for conc = 1:2 % For each concentration
    % uPA treated
    par1 = data(conc+1).peak_freq./repmat(mean(data(1).peak_freq,2),1,2); % Normalisation of treated parameter
    loc1 = x_positions(2,conc*2-1:conc*2); % Location of treated parameter
    plot(loc1,par1,'-','color',plot_color{1}) % Connecting lines
    plot(loc1,par1,'.','markersize',dot_size,'color',plot_color{1}) % Data points
    plot([loc1(1)-horz_bar_length/2 loc1(1)+horz_bar_length/2],[nanmean(par1(:,1)) nanmean(par1(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc1(2)-horz_bar_length/2 loc1(2)+horz_bar_length/2],[nanmean(par1(:,2)) nanmean(par1(:,2))],'k','linewidth',horz_bar_width) % Average
    % DMSO treated
    par2 = data(conc+4).peak_freq./repmat(mean(data(4).peak_freq,2),1,2); % Normalisation of control parameter
    loc2 = x_positions(1,conc*2-1:conc*2); % Location of control parameter
    plot(loc2,par2','-','color',plot_color{2}) % Connecting lines
    plot(loc2,par2','.','markersize',dot_size,'color',plot_color{2}+0.1) % Data points
    plot([loc2(1)-horz_bar_length/2 loc2(1)+horz_bar_length/2],[nanmean(par2(:,1)) nanmean(par2(:,1))],'k','linewidth',horz_bar_width) % Average
    plot([loc2(2)-horz_bar_length/2 loc2(2)+horz_bar_length/2],[nanmean(par2(:,2)) nanmean(par2(:,2))],'k','linewidth',horz_bar_width) % Average
    % Statistics
    for i = 1:n_bins % For each period
        x1 = par1(:,i); x1(~isfinite(x1)) = []; % Removing infinite values
        x2 = par2(:,i); x2(~isfinite(x2)) = []; % Removing infinite values
        stat = MWUtest(x1,x2,0); % Mann-Whitney U test
        sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
        if any(sig); sigstar({[loc2(:,i),loc1(:,i)]},sig_levels(sig(end))); end % Plotting in case of significance
    end
end
plot(x_positions(2,2:3),[data(2).peak_freq(:,2) data(3).peak_freq(:,1)]./repmat(mean(data(1).peak_freq,2),1,2),'-.','color',plot_color_shaded{1}) % Connecting lines
plot(x_positions(1,2:3),[data(5).peak_freq(:,2) data(6).peak_freq(:,1)]./repmat(mean(data(4).peak_freq,2),1,2),'-.','color',plot_color_shaded{2}) % Connecting lines
% Formating
set(gca,'xlim',[0.5 2.5*inter_sp],'xticklabel',xlab,'xtick',sort(x_positions(:)),'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Normalised dominant frequency','fontsize',fnt_size(1),'fontname',typeface)
ax_lab_pos = mean(reshape(x_positions',2,4)); x_lim = get(gca,'xlim'); % Calculating position of concentration labels
rel_lab_pos = (ax_lab_pos-x_lim(1))/diff(x_lim); axis_pos = get(gca,'position'); % Calculating position of concentration labels
lab_pos = rel_lab_pos*axis_pos(3) + axis_pos(1); % Calculating position of concentration labels
for i = 1:length(lab_pos) % Adding concentration labels
    annotation('textbox','position',[lab_pos(i)-textbox_length/2 axis_pos(2)-.07 textbox_length textbox_height],'string',conc_lab{~rem(i,2)+1},'edgecolor','none','horizontalalignment','center','verticalalignment','middle','fontsize',fnt_size(2),'fontname',typeface)
end

print(fig2,'-dpdf','-loose',strcat(save_path,filesep,'Burst profile')); % Saving figure as pdf
print(fig2,'-djpeg','-loose',strcat(save_path,filesep,'Burst profile')); % Saving figure as jpeg
close(fig2)


%%
% ------------- % Plot 3 % ------------- %
[fig3,ax] = populated_fig([35 25],[0.08 0.10],[0.10 0.10],[2 2],0);
x_positions = [.75 1.25 1.75 2.25];

% CPEAK BEFORE VS CPEAK AFTER SPREAD: REPRESENTATIVE EXAMPLE
pos = 1; axes(ax(pos)); hold(ax(pos),'on'); sub1 = 9; sub2 = 3;
plot(data(1).peak_matrix{sub1}(:), data(3).peak_matrix{sub1}(:),'.','color',plot_color{1}); % CC of treated representative example
plot(data(4).peak_matrix{sub2}(:), data(6).peak_matrix{sub2}(:),'.','color',plot_color{2}); % CC of control representative example
plot([0,.4],[0,.4],'k--');set(gca,'fontsize',fnt_size(2),'fontname',typeface)
xlabel('C_b_e_f_o_r_e','fontsize',fnt_size(1),'fontname',typeface); ylabel('C_a_f_t_e_r','fontsize',fnt_size(1),'fontname',typeface);

dcc = cell(1,4); mean_dcc = cell(1,4); disp_dcc = cell(1,4); % Initialising variables
for group = 1:4
    for sub = 1:length(all_cc_delta{group})
        dcc{group}{sub} = log10(all_cc_delta{group}{sub}(:)); % Log10 transform of CC change
        mean_dcc{group}(sub) = nanmean(dcc{group}{sub}); % Mean of CC change histograms
        disp_dcc{group}(sub) = nanstd(dcc{group}{sub}); % Dispersion of CC change histograms
    end
end

% CPEAK CHANGE HISTOGRAM: REPRESENTATIVE EXAMPLE
pos = 2; axes(ax(pos)); hold(ax(pos),'on'); set(gca,'fontsize',fnt_size(2),'ylim',[0 150])
hist(dcc{2}{sub1},20); hist(dcc{4}{sub2},20); hs = get(gca,'child'); % Plotting histograms of CC change
plot([mean_dcc{2}(sub1) mean_dcc{2}(sub1)],[0 150],'k--','linewidth',2); % Plotting average
plot([mean_dcc{4}(sub2) mean_dcc{4}(sub2)],[0 150],'k--','linewidth',2); % Plotting average
% Formating
set(hs(2),'FaceColor',plot_color{1},'EdgeColor','w'); set(hs(1),'FaceColor',plot_color{2},'EdgeColor','w'); set(gca,'fontname',typeface)
xlabel('log ( \DeltaC_ )','fontsize',fnt_size(1),'fontname',typeface); ylabel('Occurences','fontsize',fnt_size(1),'fontname',typeface)

% MEAN CPEAK CHANGE
pos = 3; axes(ax(pos)); hold(ax(pos),'on');
for conc = 1:2 % For each concentration
    % uPA treated
    plot(x_positions(conc+2),mean_dcc{conc},'.','markersize',dot_size,'color',plot_color{1}) % Data points
    plot([-horz_bar_length/2 horz_bar_length/2]+x_positions(conc+2),[nanmean(mean_dcc{conc}) nanmean(mean_dcc{conc})],'k','linewidth',horz_bar_width) % Average
    % DMSO treated
    plot(x_positions(conc),mean_dcc{conc+2},'.','markersize',dot_size,'color',plot_color{2}) % Data points
    plot([-horz_bar_length/2 horz_bar_length/2]+x_positions(conc),[nanmean(mean_dcc{conc+2}) nanmean(mean_dcc{conc+2})],'k','linewidth',horz_bar_width) % Average
    % Statistics
    stat = MWUtest(mean_dcc{conc},mean_dcc{conc+2},0); % Mann-Whitney U test
    sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
    if any(sig); sigstar({[x_positions(conc),x_positions(conc+2)]},sig_levels(sig(end))); end % Plotting in case of significance
end
plot(x_positions(3:4),[mean_dcc{1}' mean_dcc{2}'],'-','color',plot_color{1}) % Connecting lines
plot(x_positions(1:2),[mean_dcc{3}' mean_dcc{4}'],'-','color',plot_color{2}) % Connecting lines
% Formating
set(gca,'xlim',[0.5 2.5],'xticklabel',{'100 nM','10 M'},'xtick',x_positions,'ytick',-.5:.25:.5,'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Mean log ( \DeltaC )','fontsize',fnt_size(1),'fontname',typeface)

% STD CPEAK CHANGE
pos = 4; axes(ax(pos)); hold(ax(pos),'on');
for conc = 1:2 % For each concentration
    % uPA treated
    plot(x_positions(conc+2),disp_dcc{conc},'.','markersize',dot_size,'color',plot_color{1}) % Data points
    plot([-horz_bar_length/2 horz_bar_length/2]+x_positions(conc+2),[nanmean(disp_dcc{conc}) nanmean(disp_dcc{conc})],'k','linewidth',horz_bar_width) % Average
    % DMSO treated
    plot(x_positions(conc),disp_dcc{conc+2},'.','markersize',dot_size,'color',plot_color{2}+0.1) % Data points
    plot([-horz_bar_length/2 horz_bar_length/2]+x_positions(conc),[nanmean(disp_dcc{conc+2}) nanmean(disp_dcc{conc+2})],'k','linewidth',horz_bar_width) % Average
    % Statistics
    stat = MWUtest(disp_dcc{conc},disp_dcc{conc+2},0); % Mann-Whitney U test
    sig = find(stat.p(2) < sig_levels); % Checking p-value with significance levels
    if any(sig); sigstar({[x_positions(conc),x_positions(conc+2)]},sig_levels(sig(end))); end % Plotting in case of significance
end
plot(x_positions(3:4),[disp_dcc{1}' disp_dcc{2}'],'-','color',plot_color{1}) % Connecting lines
plot(x_positions(1:2),[disp_dcc{3}' disp_dcc{4}'],'-','color',plot_color{2}) % Connecting lines
% Formating
set(gca,'xlim',[0.5 2.5],'xticklabel',{'100 nM','10 M'},'xtick',x_positions,'fontsize',fnt_size(2),'fontname',typeface)
ylabel('Dispersion of log ( \DeltaC )','fontsize',fnt_size(1),'fontname',typeface)

print(fig3,'-dpdf','-loose',strcat(save_path,filesep,'Cross correlation')); % Saving figure as pdf
print(fig3,'-djpeg','-loose',strcat(save_path,filesep,'Cross correlation')); % Saving figure as jpeg
close(fig3)


fprintf('\n--- ANALYSIS COMPLETE! ---\n')
close all


