function [shifted_burstprof,time_profile,psd,freq,shift,R_after] = burst_alignment(bursts,spikes,plt,remove_offset)
% Align bursts in such a way as to maximise their correlation. It returns
% the shifted bursts (shifted_burstprof), their time axis (time_profile),
% their frequency spectrum (psd), frequency axis (freq), shift values
% (shift) and correlation values after shifting (R_after)
% 
% Set plt to 1 to inspect the result of the alignment
% Set remove_offset to 1 to remove the 0 Hz component of the spectral analysis


% Rocco Pulizzi & Sebastiaan Van De Vijver

%% LOADING DATA

t1 = 0.20; % Time before burst peak to consider (sec)
t2 = 0.50; % Time after burst peak to consider (sec)
bin = 0.001; % Resolution of burst profile (sec)
bursts = bursts/1e3; % Translating times to second scale
spikes = spikes/1e3; % Translating times to second scale
time_profile = -t1:bin:t2-bin; % Time axis
burst_profile = nan(size(bursts,1),length(time_profile)+1); t_burst = burst_profile;
for kk = 1:size(bursts,1)
    t1_burst = bursts(kk,:) - t1; % Start time
    t2_burst = bursts(kk,:) + t2; % End time
    spk = spikes(spikes(:,1) >= t1_burst & spikes(:,1) < t2_burst,1); % Selecting spikes within time limits
    burst_profile(kk,:) = histc(spk,t1_burst:bin:t2_burst)/59/bin; % Constructing histogram
    t_burst(kk,:) = t1_burst:bin:t2_burst; % Time axis
end
burst_profile(:,end) = []; % Removing trailing edge of histc


%% ALIGNMENT
% The alignment algorithm works by maximising correlation of all bursts to
% the first burst, which in some cases is not a good representative burst
% (due to chance and burst detection thresholds), leading to bad alignment.
% Each time this script is run, the order of the bursts is shuffled and so
% a random burst is taken as reference instead of the first. Bad alignment
% (and thus necessity to run script again) can be detected by the R_after
% output variable: the mean correlation should be high.

norm_burst_profile = burst_profile/max(burst_profile(:)); % Normalise
ref_burst_ind = randi(size(burst_profile,1),1); % Random index
ref_burstprof_norm = norm_burst_profile(ref_burst_ind,:); % Take a random burst as reference
R_before = nan(size(norm_burst_profile,1),1); R_after = R_before; shift = R_before; % Initialising variables
shifted_burstprof = nan(size(burst_profile)); shifted_burstprof_norm = shifted_burstprof; % Initialising variables
for i = 1:size(norm_burst_profile,1) % Alignment for each burst
    burstprof_norm = norm_burst_profile(i,:); % Normalised burst
    burstprof = burst_profile(i,:); % Burst
    tmp = corrcoef(ref_burstprof_norm,burstprof_norm); % Calculating correlation
    R_before(i) = tmp(2,1); % Degree of correlation before alignment
    shift(i) = finddelay(ref_burstprof_norm,burstprof_norm); % Estimate time shift to maximise correlation
    % Shift and zero-pad second burst profile
    if shift(i) > 0
        shifted_burstprof_norm(i,:) = [burstprof_norm(shift(i)+1:end) zeros(1,abs(shift(i)))];
        shifted_burstprof(i,:) = [burstprof(shift(i)+1:end) zeros(1,abs(shift(i)))];
    else
        shifted_burstprof_norm(i,:) = [zeros(1,abs(shift(i))) burstprof_norm(1:end-(abs(shift(i))))];
        shifted_burstprof(i,:) = [zeros(1,abs(shift(i))) burstprof(1:end-(abs(shift(i))))];
    end
    tmp = corrcoef(ref_burstprof_norm,shifted_burstprof_norm(i,:)); % Calculating correlation
    R_after(i) = tmp(2,1); % Degree of correlation after alignment
end

% Spectral analysis
% Set remove_offset to 1 to remove the 0 Hz component of the spectral analysis
warning('off','MATLAB:colon:nonIntegerIndex');
for i = 1:size(shifted_burstprof,1)
    if remove_offset; [freq, psdx] = estimate_psd(detrend(shifted_burstprof_norm(i,:)),1e3);
    else, [freq, psdx] = estimate_psd(shifted_burstprof_norm(i,:),1e3);
    end
    psd(i,:) = psdx; %#ok<AGROW>
end


%% PLOTTING

if plt
    figure('color','w','position',[1 31 1920 973],'DefaultAxesFontSize',12,'DefaultTextFontSize',12);
    % Aligned burst profiles
    ax(1) = axes('Position',[0.1 0.67 0.825 0.3]);
    plot(time_profile,mean(shifted_burstprof,1),'k','Linewidth',2)
    ylabel('Firing rate (Hz)'); title('Average aligned burst')

    % Inset
    ax(2) = axes('Position',[0.675 0.80 0.25 0.15]);
    plot(time_profile,burst_profile(ref_burst_ind,:),'k')
    title(sprintf('Reference burst (nr %.0f)',ref_burst_ind)); ylabel('FR');
    
    % Aligned bursts
    ax(3) = axes('Position',[0.1 0.32 0.825 0.3]);
    imagesc(time_profile,1:size(shifted_burstprof,1),shifted_burstprof);
    colorbar('location','eastoutside'); set(gca,'ydir','normal')
    xlabel('Time (s)'); ylabel('Burst index'); colormap('copper')
    
    % R plot
    ax(4) = axes('Position',[0.1 0.09 0.15 0.15]); hold on
    plot(R_before,R_after,'.k','markersize',20); plot([0 max(R_before)],[0 max(R_after)],'--k');
    xlabel('R before'); ylabel('R after'); title('Correlation change')
    
    % Burst profiles
    ax(5) = axes('Position',[0.325 0.09 0.15 0.15]);
    plot(time_profile,mean(burst_profile,1),'k','linewidth',2)
    xlabel('Time (s)'); ylabel('Firing rate (Hz)');
    title('Average non-aligned burst')
    
    % Alignment delays
    ax(6) = axes('Position',[0.55 0.09 0.15 0.15]);
    hh = histc(shift,min(shift):1:max(shift));
    bar(min(shift):1:max(shift),hh,'histc');
    xlabel('Delay (ms)'); ylabel('Count');
    title('Alignment delay histogram')
    
    % PSD
    ax(7) = axes('Position',[0.775 0.09 0.15 0.15]);
    mean_psd = mean(psd,1); m = max(mean_psd(10:end))*1.5;
    plot(freq,mean_psd,'k','linewidth',2)
    xlabel('Frequency (Hz)'); ylabel('Power'); title('PSD')
    xlim([0 200]), ylim([0 m])

    set(ax,'box','off','tickdir','out','ticklength',[0.002 0.025]); axis(ax(2:6),'tight');
    
end